@@ -51,6 +51,7 @@ main(int argc, char *argv[])
     rc = test_establish_contexts(
         &init_ctx,
         &accept_ctx,
+        0,
         &context_major_status,
         &context_minor_status);
 
@@ -152,6 +153,5 @@ establish_failed:
     {
         gss_delete_sec_context(&release_minor_status, &accept_ctx, NULL);
     }
-auth_fail:
     return failed;
 }
